Alsa-Devel Archive on lore.kernel.org
 help / color / mirror / Atom feed
* [PATCH 0/7] ASoC updates
@ 2008-12-01 20:07 Mark Brown
  2008-12-01 20:07 ` [PATCH 1/7] ASoC: Rename snd_soc_register_card() to snd_soc_init_card() Mark Brown
  2008-12-01 20:31 ` [PATCH 0/7] ASoC updates Takashi Iwai
  0 siblings, 2 replies; 13+ messages in thread
From: Mark Brown @ 2008-12-01 20:07 UTC (permalink / raw)
  To: Takashi Iwai; +Cc: alsa-devel

The following changes since commit 682d5874f3d654b5d13d9b8dd56b9e05cfadd01b:
  Takashi Iwai (1):
        ALSA: ASoC: Fix old-style trigger callback in s3c2443-ac97.c

are available in the git repository at:

  git://opensource.wolfsonmicro.com/linux-2.6-asoc for-tiwai

Mark Brown (4):
      ASoC: Rename snd_soc_register_card() to snd_soc_init_card()
      ASoC: Annotate core removal function
      ASoC: Remove in-code changelog from AD73311 driver
      ASoC: Don't free static data in WM9713

Peter Ujfalusi (3):
      ASoC: TWL4030: Change the capture volume control to TLV
      ASoC: TWL4030: Change the common playback volume controls
      ASoC: TWL4030: Add volume controls for outputs

 include/sound/soc.h            |    2 +-
 sound/soc/codecs/ac97.c        |    2 +-
 sound/soc/codecs/ad1980.c      |    2 +-
 sound/soc/codecs/ad73311.c     |    5 +--
 sound/soc/codecs/ak4535.c      |    2 +-
 sound/soc/codecs/cs4270.c      |    2 +-
 sound/soc/codecs/pcm3008.c     |    2 +-
 sound/soc/codecs/ssm2602.c     |    2 +-
 sound/soc/codecs/tlv320aic23.c |    2 +-
 sound/soc/codecs/tlv320aic26.c |    2 +-
 sound/soc/codecs/tlv320aic3x.c |    2 +-
 sound/soc/codecs/twl4030.c     |   74 +++++++++++++++++++++++++++++++++------
 sound/soc/codecs/uda134x.c     |    2 +-
 sound/soc/codecs/uda1380.c     |    2 +-
 sound/soc/codecs/wm8510.c      |    2 +-
 sound/soc/codecs/wm8580.c      |    2 +-
 sound/soc/codecs/wm8728.c      |    2 +-
 sound/soc/codecs/wm8731.c      |    2 +-
 sound/soc/codecs/wm8750.c      |    2 +-
 sound/soc/codecs/wm8753.c      |    2 +-
 sound/soc/codecs/wm8900.c      |    2 +-
 sound/soc/codecs/wm8903.c      |    2 +-
 sound/soc/codecs/wm8971.c      |    2 +-
 sound/soc/codecs/wm8990.c      |    2 +-
 sound/soc/codecs/wm9712.c      |    2 +-
 sound/soc/codecs/wm9713.c      |    3 +-
 sound/soc/soc-core.c           |    8 ++--
 27 files changed, 91 insertions(+), 45 deletions(-)

^ permalink raw reply	[flat|nested] 13+ messages in thread

* [PATCH 1/7] ASoC: Rename snd_soc_register_card() to snd_soc_init_card()
  2008-12-01 20:07 [PATCH 0/7] ASoC updates Mark Brown
@ 2008-12-01 20:07 ` Mark Brown
  2008-12-01 20:07   ` [PATCH 2/7] ASoC: Annotate core removal function Mark Brown
  2008-12-01 20:31 ` [PATCH 0/7] ASoC updates Takashi Iwai
  1 sibling, 1 reply; 13+ messages in thread
From: Mark Brown @ 2008-12-01 20:07 UTC (permalink / raw)
  To: Takashi Iwai; +Cc: alsa-devel, Mark Brown

Currently ASoC card initialisation is completed by a function called
snd_soc_register_card().  As part of the work to allow independant
registration of cards, codecs and machines in ASoC v2 a new function of
the same name has been added so rename the existing function to
facilitate the merge of v2.

Signed-off-by: Mark Brown <broonie@opensource.wolfsonmicro.com>
---
 include/sound/soc.h            |    2 +-
 sound/soc/codecs/ac97.c        |    2 +-
 sound/soc/codecs/ad1980.c      |    2 +-
 sound/soc/codecs/ad73311.c     |    2 +-
 sound/soc/codecs/ak4535.c      |    2 +-
 sound/soc/codecs/cs4270.c      |    2 +-
 sound/soc/codecs/pcm3008.c     |    2 +-
 sound/soc/codecs/ssm2602.c     |    2 +-
 sound/soc/codecs/tlv320aic23.c |    2 +-
 sound/soc/codecs/tlv320aic26.c |    2 +-
 sound/soc/codecs/tlv320aic3x.c |    2 +-
 sound/soc/codecs/twl4030.c     |    2 +-
 sound/soc/codecs/uda134x.c     |    2 +-
 sound/soc/codecs/uda1380.c     |    2 +-
 sound/soc/codecs/wm8510.c      |    2 +-
 sound/soc/codecs/wm8580.c      |    2 +-
 sound/soc/codecs/wm8728.c      |    2 +-
 sound/soc/codecs/wm8731.c      |    2 +-
 sound/soc/codecs/wm8750.c      |    2 +-
 sound/soc/codecs/wm8753.c      |    2 +-
 sound/soc/codecs/wm8900.c      |    2 +-
 sound/soc/codecs/wm8903.c      |    2 +-
 sound/soc/codecs/wm8971.c      |    2 +-
 sound/soc/codecs/wm8990.c      |    2 +-
 sound/soc/codecs/wm9712.c      |    2 +-
 sound/soc/codecs/wm9713.c      |    2 +-
 sound/soc/soc-core.c           |    6 +++---
 27 files changed, 29 insertions(+), 29 deletions(-)

diff --git a/include/sound/soc.h b/include/sound/soc.h
index 444f9c2..9356c1c 100644
--- a/include/sound/soc.h
+++ b/include/sound/soc.h
@@ -162,7 +162,7 @@ extern struct snd_ac97_bus_ops soc_ac97_ops;
 /* pcm <-> DAI connect */
 void snd_soc_free_pcms(struct snd_soc_device *socdev);
 int snd_soc_new_pcms(struct snd_soc_device *socdev, int idx, const char *xid);
-int snd_soc_register_card(struct snd_soc_device *socdev);
+int snd_soc_init_card(struct snd_soc_device *socdev);
 
 /* set runtime hw params */
 int snd_soc_set_runtime_hwparams(struct snd_pcm_substream *substream,
diff --git a/sound/soc/codecs/ac97.c b/sound/soc/codecs/ac97.c
index c4208c8..fb53e65 100644
--- a/sound/soc/codecs/ac97.c
+++ b/sound/soc/codecs/ac97.c
@@ -114,7 +114,7 @@ static int ac97_soc_probe(struct platform_device *pdev)
 	if (ret < 0)
 		goto bus_err;
 
-	ret = snd_soc_register_card(socdev);
+	ret = snd_soc_init_card(socdev);
 	if (ret < 0)
 		goto bus_err;
 	return 0;
diff --git a/sound/soc/codecs/ad1980.c b/sound/soc/codecs/ad1980.c
index a9a2681..73fdbb4 100644
--- a/sound/soc/codecs/ad1980.c
+++ b/sound/soc/codecs/ad1980.c
@@ -270,7 +270,7 @@ static int ad1980_soc_probe(struct platform_device *pdev)
 	ac97_write(codec, AC97_EXTENDED_STATUS, ext_status&~0x3800);
 
 	ad1980_add_controls(codec);
-	ret = snd_soc_register_card(socdev);
+	ret = snd_soc_init_card(socdev);
 	if (ret < 0) {
 		printk(KERN_ERR "ad1980: failed to register card\n");
 		goto reset_err;
diff --git a/sound/soc/codecs/ad73311.c b/sound/soc/codecs/ad73311.c
index 59c4c8f..0f4110f 100644
--- a/sound/soc/codecs/ad73311.c
+++ b/sound/soc/codecs/ad73311.c
@@ -67,7 +67,7 @@ static int ad73311_soc_probe(struct platform_device *pdev)
 		goto pcm_err;
 	}
 
-	ret = snd_soc_register_card(socdev);
+	ret = snd_soc_init_card(socdev);
 	if (ret < 0) {
 		printk(KERN_ERR "ad73311: failed to register card\n");
 		goto register_err;
diff --git a/sound/soc/codecs/ak4535.c b/sound/soc/codecs/ak4535.c
index c742290..23062c9 100644
--- a/sound/soc/codecs/ak4535.c
+++ b/sound/soc/codecs/ak4535.c
@@ -512,7 +512,7 @@ static int ak4535_init(struct snd_soc_device *socdev)
 
 	ak4535_add_controls(codec);
 	ak4535_add_widgets(codec);
-	ret = snd_soc_register_card(socdev);
+	ret = snd_soc_init_card(socdev);
 	if (ret < 0) {
 		printk(KERN_ERR "ak4535: failed to register card\n");
 		goto card_err;
diff --git a/sound/soc/codecs/cs4270.c b/sound/soc/codecs/cs4270.c
index 7507d46..4667a07 100644
--- a/sound/soc/codecs/cs4270.c
+++ b/sound/soc/codecs/cs4270.c
@@ -723,7 +723,7 @@ static int cs4270_probe(struct platform_device *pdev)
 	printk(KERN_INFO "cs4270: I2C disabled, using stand-alone mode\n");
 #endif
 
-	ret = snd_soc_register_card(socdev);
+	ret = snd_soc_init_card(socdev);
 	if (ret < 0) {
 		printk(KERN_ERR "cs4270: failed to register card\n");
 		goto error_del_driver;
diff --git a/sound/soc/codecs/pcm3008.c b/sound/soc/codecs/pcm3008.c
index 651a15e..a586255 100644
--- a/sound/soc/codecs/pcm3008.c
+++ b/sound/soc/codecs/pcm3008.c
@@ -91,7 +91,7 @@ static int pcm3008_soc_probe(struct platform_device *pdev)
 	}
 
 	/* Register Card. */
-	ret = snd_soc_register_card(socdev);
+	ret = snd_soc_init_card(socdev);
 	if (ret < 0) {
 		printk(KERN_ERR "pcm3008: failed to register card\n");
 		goto card_err;
diff --git a/sound/soc/codecs/ssm2602.c b/sound/soc/codecs/ssm2602.c
index 0c5884e..9738449 100644
--- a/sound/soc/codecs/ssm2602.c
+++ b/sound/soc/codecs/ssm2602.c
@@ -624,7 +624,7 @@ static int ssm2602_init(struct snd_soc_device *socdev)
 
 	ssm2602_add_controls(codec);
 	ssm2602_add_widgets(codec);
-	ret = snd_soc_register_card(socdev);
+	ret = snd_soc_init_card(socdev);
 	if (ret < 0) {
 		pr_err("ssm2602: failed to register card\n");
 		goto card_err;
diff --git a/sound/soc/codecs/tlv320aic23.c b/sound/soc/codecs/tlv320aic23.c
index a4e13d0..d209bec 100644
--- a/sound/soc/codecs/tlv320aic23.c
+++ b/sound/soc/codecs/tlv320aic23.c
@@ -720,7 +720,7 @@ static int tlv320aic23_init(struct snd_soc_device *socdev)
 
 	tlv320aic23_add_controls(codec);
 	tlv320aic23_add_widgets(codec);
-	ret = snd_soc_register_card(socdev);
+	ret = snd_soc_init_card(socdev);
 	if (ret < 0) {
 		printk(KERN_ERR "tlv320aic23: failed to register card\n");
 		goto card_err;
diff --git a/sound/soc/codecs/tlv320aic26.c b/sound/soc/codecs/tlv320aic26.c
index 6b7ddfc..e33fb7e 100644
--- a/sound/soc/codecs/tlv320aic26.c
+++ b/sound/soc/codecs/tlv320aic26.c
@@ -359,7 +359,7 @@ static int aic26_probe(struct platform_device *pdev)
 
 	/* CODEC is setup, we can register the card now */
 	dev_dbg(&pdev->dev, "Registering card\n");
-	ret = snd_soc_register_card(socdev);
+	ret = snd_soc_init_card(socdev);
 	if (ret < 0) {
 		dev_err(&pdev->dev, "aic26: failed to register card\n");
 		goto card_err;
diff --git a/sound/soc/codecs/tlv320aic3x.c b/sound/soc/codecs/tlv320aic3x.c
index 255e784..0f4067b 100644
--- a/sound/soc/codecs/tlv320aic3x.c
+++ b/sound/soc/codecs/tlv320aic3x.c
@@ -1187,7 +1187,7 @@ static int aic3x_init(struct snd_soc_device *socdev)
 
 	aic3x_add_controls(codec);
 	aic3x_add_widgets(codec);
-	ret = snd_soc_register_card(socdev);
+	ret = snd_soc_init_card(socdev);
 	if (ret < 0) {
 		printk(KERN_ERR "aic3x: failed to register card\n");
 		goto card_err;
diff --git a/sound/soc/codecs/twl4030.c b/sound/soc/codecs/twl4030.c
index 4136231..f3e9e59 100644
--- a/sound/soc/codecs/twl4030.c
+++ b/sound/soc/codecs/twl4030.c
@@ -764,7 +764,7 @@ static int twl4030_init(struct snd_soc_device *socdev)
 	twl4030_add_controls(codec);
 	twl4030_add_widgets(codec);
 
-	ret = snd_soc_register_card(socdev);
+	ret = snd_soc_init_card(socdev);
 	if (ret < 0) {
 		printk(KERN_ERR "twl4030: failed to register card\n");
 		goto card_err;
diff --git a/sound/soc/codecs/uda134x.c b/sound/soc/codecs/uda134x.c
index 91f333c..58de749 100644
--- a/sound/soc/codecs/uda134x.c
+++ b/sound/soc/codecs/uda134x.c
@@ -578,7 +578,7 @@ static int uda134x_soc_probe(struct platform_device *pdev)
 		goto pcm_err;
 	}
 
-	ret = snd_soc_register_card(socdev);
+	ret = snd_soc_init_card(socdev);
 	if (ret < 0) {
 		printk(KERN_ERR "UDA134X: failed to register card\n");
 		goto card_err;
diff --git a/sound/soc/codecs/uda1380.c b/sound/soc/codecs/uda1380.c
index 330877c..4249165 100644
--- a/sound/soc/codecs/uda1380.c
+++ b/sound/soc/codecs/uda1380.c
@@ -677,7 +677,7 @@ static int uda1380_init(struct snd_soc_device *socdev, int dac_clk)
 	/* uda1380 init */
 	uda1380_add_controls(codec);
 	uda1380_add_widgets(codec);
-	ret = snd_soc_register_card(socdev);
+	ret = snd_soc_init_card(socdev);
 	if (ret < 0) {
 		pr_err("uda1380: failed to register card\n");
 		goto card_err;
diff --git a/sound/soc/codecs/wm8510.c b/sound/soc/codecs/wm8510.c
index 173b66c..126c70f 100644
--- a/sound/soc/codecs/wm8510.c
+++ b/sound/soc/codecs/wm8510.c
@@ -658,7 +658,7 @@ static int wm8510_init(struct snd_soc_device *socdev)
 	wm8510_set_bias_level(codec, SND_SOC_BIAS_STANDBY);
 	wm8510_add_controls(codec);
 	wm8510_add_widgets(codec);
-	ret = snd_soc_register_card(socdev);
+	ret = snd_soc_init_card(socdev);
 	if (ret < 0) {
 		printk(KERN_ERR "wm8510: failed to register card\n");
 		goto card_err;
diff --git a/sound/soc/codecs/wm8580.c b/sound/soc/codecs/wm8580.c
index 220d4b6..572a31d 100644
--- a/sound/soc/codecs/wm8580.c
+++ b/sound/soc/codecs/wm8580.c
@@ -869,7 +869,7 @@ static int wm8580_init(struct snd_soc_device *socdev)
 	wm8580_add_controls(codec);
 	wm8580_add_widgets(codec);
 
-	ret = snd_soc_register_card(socdev);
+	ret = snd_soc_init_card(socdev);
 	if (ret < 0) {
 		printk(KERN_ERR "wm8580: failed to register card\n");
 		goto card_err;
diff --git a/sound/soc/codecs/wm8728.c b/sound/soc/codecs/wm8728.c
index 71949bd..28f12c6 100644
--- a/sound/soc/codecs/wm8728.c
+++ b/sound/soc/codecs/wm8728.c
@@ -332,7 +332,7 @@ static int wm8728_init(struct snd_soc_device *socdev)
 
 	wm8728_add_controls(codec);
 	wm8728_add_widgets(codec);
-	ret = snd_soc_register_card(socdev);
+	ret = snd_soc_init_card(socdev);
 	if (ret < 0) {
 		printk(KERN_ERR "wm8728: failed to register card\n");
 		goto card_err;
diff --git a/sound/soc/codecs/wm8731.c b/sound/soc/codecs/wm8731.c
index c0f2770..403dea1 100644
--- a/sound/soc/codecs/wm8731.c
+++ b/sound/soc/codecs/wm8731.c
@@ -545,7 +545,7 @@ static int wm8731_init(struct snd_soc_device *socdev)
 
 	wm8731_add_controls(codec);
 	wm8731_add_widgets(codec);
-	ret = snd_soc_register_card(socdev);
+	ret = snd_soc_init_card(socdev);
 	if (ret < 0) {
 		printk(KERN_ERR "wm8731: failed to register card\n");
 		goto card_err;
diff --git a/sound/soc/codecs/wm8750.c b/sound/soc/codecs/wm8750.c
index 860a1d5..979446f 100644
--- a/sound/soc/codecs/wm8750.c
+++ b/sound/soc/codecs/wm8750.c
@@ -818,7 +818,7 @@ static int wm8750_init(struct snd_soc_device *socdev)
 
 	wm8750_add_controls(codec);
 	wm8750_add_widgets(codec);
-	ret = snd_soc_register_card(socdev);
+	ret = snd_soc_init_card(socdev);
 	if (ret < 0) {
 		printk(KERN_ERR "wm8750: failed to register card\n");
 		goto card_err;
diff --git a/sound/soc/codecs/wm8753.c b/sound/soc/codecs/wm8753.c
index 5e4cd3b..96c0453 100644
--- a/sound/soc/codecs/wm8753.c
+++ b/sound/soc/codecs/wm8753.c
@@ -1605,7 +1605,7 @@ static int wm8753_init(struct snd_soc_device *socdev)
 
 	wm8753_add_controls(codec);
 	wm8753_add_widgets(codec);
-	ret = snd_soc_register_card(socdev);
+	ret = snd_soc_init_card(socdev);
 	if (ret < 0) {
 		printk(KERN_ERR "wm8753: failed to register card\n");
 		goto card_err;
diff --git a/sound/soc/codecs/wm8900.c b/sound/soc/codecs/wm8900.c
index d1326be..29cd839 100644
--- a/sound/soc/codecs/wm8900.c
+++ b/sound/soc/codecs/wm8900.c
@@ -1365,7 +1365,7 @@ static int wm8900_init(struct snd_soc_device *socdev)
 	wm8900_add_controls(codec);
 	wm8900_add_widgets(codec);
 
-	ret = snd_soc_register_card(socdev);
+	ret = snd_soc_init_card(socdev);
 	if (ret < 0) {
 		dev_err(&i2c_client->dev, "Failed to register card\n");
 		goto card_err;
diff --git a/sound/soc/codecs/wm8903.c b/sound/soc/codecs/wm8903.c
index efbe892..393a4c1 100644
--- a/sound/soc/codecs/wm8903.c
+++ b/sound/soc/codecs/wm8903.c
@@ -1648,7 +1648,7 @@ static int wm8903_init(struct snd_soc_device *socdev)
 
 	wm8903_add_controls(codec);
 	wm8903_add_widgets(codec);
-	ret = snd_soc_register_card(socdev);
+	ret = snd_soc_init_card(socdev);
 	if (ret < 0) {
 		dev_err(&i2c->dev, "wm8903: failed to register card\n");
 		goto card_err;
diff --git a/sound/soc/codecs/wm8971.c b/sound/soc/codecs/wm8971.c
index 26edcc9..53e6937 100644
--- a/sound/soc/codecs/wm8971.c
+++ b/sound/soc/codecs/wm8971.c
@@ -747,7 +747,7 @@ static int wm8971_init(struct snd_soc_device *socdev)
 
 	wm8971_add_controls(codec);
 	wm8971_add_widgets(codec);
-	ret = snd_soc_register_card(socdev);
+	ret = snd_soc_init_card(socdev);
 	if (ret < 0) {
 		printk(KERN_ERR "wm8971: failed to register card\n");
 		goto card_err;
diff --git a/sound/soc/codecs/wm8990.c b/sound/soc/codecs/wm8990.c
index 1392651..5c5128b 100644
--- a/sound/soc/codecs/wm8990.c
+++ b/sound/soc/codecs/wm8990.c
@@ -1462,7 +1462,7 @@ static int wm8990_init(struct snd_soc_device *socdev)
 
 	wm8990_add_controls(codec);
 	wm8990_add_widgets(codec);
-	ret = snd_soc_register_card(socdev);
+	ret = snd_soc_init_card(socdev);
 	if (ret < 0) {
 		printk(KERN_ERR "wm8990: failed to register card\n");
 		goto card_err;
diff --git a/sound/soc/codecs/wm9712.c b/sound/soc/codecs/wm9712.c
index 40f1406..af83d62 100644
--- a/sound/soc/codecs/wm9712.c
+++ b/sound/soc/codecs/wm9712.c
@@ -700,7 +700,7 @@ static int wm9712_soc_probe(struct platform_device *pdev)
 	wm9712_set_bias_level(codec, SND_SOC_BIAS_STANDBY);
 	wm9712_add_controls(codec);
 	wm9712_add_widgets(codec);
-	ret = snd_soc_register_card(socdev);
+	ret = snd_soc_init_card(socdev);
 	if (ret < 0) {
 		printk(KERN_ERR "wm9712: failed to register card\n");
 		goto reset_err;
diff --git a/sound/soc/codecs/wm9713.c b/sound/soc/codecs/wm9713.c
index 9dad0bf..49962a8 100644
--- a/sound/soc/codecs/wm9713.c
+++ b/sound/soc/codecs/wm9713.c
@@ -1247,7 +1247,7 @@ static int wm9713_soc_probe(struct platform_device *pdev)
 
 	wm9713_add_controls(codec);
 	wm9713_add_widgets(codec);
-	ret = snd_soc_register_card(socdev);
+	ret = snd_soc_init_card(socdev);
 	if (ret < 0)
 		goto reset_err;
 	return 0;
-- 
1.5.6.5

^ permalink raw reply related	[flat|nested] 13+ messages in thread

* [PATCH 2/7] ASoC: Annotate core removal function
  2008-12-01 20:07 ` [PATCH 1/7] ASoC: Rename snd_soc_register_card() to snd_soc_init_card() Mark Brown
@ 2008-12-01 20:07   ` Mark Brown
  2008-12-01 20:07     ` [PATCH 3/7] ASoC: Remove in-code changelog from AD73311 driver Mark Brown
  0 siblings, 1 reply; 13+ messages in thread
From: Mark Brown @ 2008-12-01 20:07 UTC (permalink / raw)
  To: Takashi Iwai; +Cc: alsa-devel, Mark Brown

Signed-off-by: Mark Brown <broonie@opensource.wolfsonmicro.com>
---
 sound/soc/soc-core.c |    2 +-
 1 files changed, 1 insertions(+), 1 deletions(-)

diff --git a/sound/soc/soc-core.c b/sound/soc/soc-core.c
index 0448708..7eb2ea1 100644
--- a/sound/soc/soc-core.c
+++ b/sound/soc/soc-core.c
@@ -1952,7 +1952,7 @@ static int __devinit snd_soc_init(void)
 	return platform_driver_register(&soc_driver);
 }
 
-static void snd_soc_exit(void)
+static void __exit snd_soc_exit(void)
 {
 	platform_driver_unregister(&soc_driver);
 }
-- 
1.5.6.5

^ permalink raw reply related	[flat|nested] 13+ messages in thread

* [PATCH 3/7] ASoC: Remove in-code changelog from AD73311 driver
  2008-12-01 20:07   ` [PATCH 2/7] ASoC: Annotate core removal function Mark Brown
@ 2008-12-01 20:07     ` Mark Brown
  2008-12-01 20:07       ` [PATCH 4/7] ASoC: TWL4030: Change the capture volume control to TLV Mark Brown
  0 siblings, 1 reply; 13+ messages in thread
From: Mark Brown @ 2008-12-01 20:07 UTC (permalink / raw)
  To: Takashi Iwai; +Cc: alsa-devel, Mark Brown

Signed-off-by: Mark Brown <broonie@opensource.wolfsonmicro.com>
---
 sound/soc/codecs/ad73311.c |    3 ---
 1 files changed, 0 insertions(+), 3 deletions(-)

diff --git a/sound/soc/codecs/ad73311.c b/sound/soc/codecs/ad73311.c
index 0f4110f..500f9f3 100644
--- a/sound/soc/codecs/ad73311.c
+++ b/sound/soc/codecs/ad73311.c
@@ -8,9 +8,6 @@
  *  under  the terms of  the GNU General  Public License as published by the
  *  Free Software Foundation;  either version 2 of the  License, or (at your
  *  option) any later version.
- *
- *  Revision history
- *    25th Sep 2008   Initial version.
  */
 
 #include <linux/init.h>
-- 
1.5.6.5

^ permalink raw reply related	[flat|nested] 13+ messages in thread

* [PATCH 4/7] ASoC: TWL4030: Change the capture volume control to TLV
  2008-12-01 20:07     ` [PATCH 3/7] ASoC: Remove in-code changelog from AD73311 driver Mark Brown
@ 2008-12-01 20:07       ` Mark Brown
  2008-12-01 20:07         ` [PATCH 5/7] ASoC: TWL4030: Change the common playback volume controls Mark Brown
  0 siblings, 1 reply; 13+ messages in thread
From: Mark Brown @ 2008-12-01 20:07 UTC (permalink / raw)
  To: Takashi Iwai; +Cc: alsa-devel, Mark Brown, Peter Ujfalusi

From: Peter Ujfalusi <peter.ujfalusi@nokia.com>

The digital Capture gain control has a range:
0 to 31 dB in 1 dB steps.

Signed-off-by: Peter Ujfalusi <peter.ujfalusi@nokia.com>
Signed-off-by: Mark Brown <broonie@opensource.wolfsonmicro.com>
---
 sound/soc/codecs/twl4030.c |   14 +++++++++++---
 1 files changed, 11 insertions(+), 3 deletions(-)

diff --git a/sound/soc/codecs/twl4030.c b/sound/soc/codecs/twl4030.c
index f3e9e59..4b7a2d1 100644
--- a/sound/soc/codecs/twl4030.c
+++ b/sound/soc/codecs/twl4030.c
@@ -360,6 +360,12 @@ static DECLARE_TLV_DB_SCALE(master_tlv, -6300, 100, 1);
  */
 static DECLARE_TLV_DB_SCALE(master_coarse_tlv, 0, 600, 0);
 
+/*
+ * Capture gain after the ADCs
+ * from 0 dB to 31 dB in 1 dB steps
+ */
+static DECLARE_TLV_DB_SCALE(digital_capture_tlv, 0, 100, 0);
+
 static const struct snd_kcontrol_new twl4030_snd_controls[] = {
 	SOC_DOUBLE_R_TLV("Master Playback Volume",
 		 TWL4030_REG_ARXL2PGA, TWL4030_REG_ARXR2PGA,
@@ -367,9 +373,11 @@ static const struct snd_kcontrol_new twl4030_snd_controls[] = {
 	SOC_DOUBLE_R_TLV("Master PCM Playback Volume",
 		 TWL4030_REG_ARXL2PGA, TWL4030_REG_ARXR2PGA,
 		6, 0x2, 0, master_coarse_tlv),
-	SOC_DOUBLE_R("Capture Volume",
-		 TWL4030_REG_ATXL1PGA, TWL4030_REG_ATXR1PGA,
-		0, 0x1f, 0),
+
+	/* Common capture gain controls */
+	SOC_DOUBLE_R_TLV("Capture Volume",
+		TWL4030_REG_ATXL1PGA, TWL4030_REG_ATXR1PGA,
+		0, 0x1f, 0, digital_capture_tlv),
 };
 
 /* add non dapm controls */
-- 
1.5.6.5

^ permalink raw reply related	[flat|nested] 13+ messages in thread

* [PATCH 5/7] ASoC: TWL4030: Change the common playback volume controls
  2008-12-01 20:07       ` [PATCH 4/7] ASoC: TWL4030: Change the capture volume control to TLV Mark Brown
@ 2008-12-01 20:07         ` Mark Brown
  2008-12-01 20:07           ` [PATCH 6/7] ASoC: TWL4030: Add volume controls for outputs Mark Brown
  0 siblings, 1 reply; 13+ messages in thread
From: Mark Brown @ 2008-12-01 20:07 UTC (permalink / raw)
  To: Takashi Iwai; +Cc: alsa-devel, Mark Brown, Peter Ujfalusi

From: Peter Ujfalusi <peter.ujfalusi@nokia.com>

Add Playback volume controls for all four DACs.
All four paths has three levels of volume controls:
Digital Fine gain, Digital Coarse gain, Analog gain.

The controls are named to reflect their connection to the DACs.
Per DAC volume can be performed, if needed:
amixer sset 'DAC1 Analog'  5,10
DACL1 analog gain to 5
DACR1 analog gain to 10

Signed-off-by: Peter Ujfalusi <peter.ujfalusi@nokia.com>
Signed-off-by: Mark Brown <broonie@opensource.wolfsonmicro.com>
---
 sound/soc/codecs/twl4030.c |   37 +++++++++++++++++++++++++++++--------
 1 files changed, 29 insertions(+), 8 deletions(-)

diff --git a/sound/soc/codecs/twl4030.c b/sound/soc/codecs/twl4030.c
index 4b7a2d1..1dae73a 100644
--- a/sound/soc/codecs/twl4030.c
+++ b/sound/soc/codecs/twl4030.c
@@ -351,14 +351,20 @@ static int snd_soc_put_volsw_r2_twl4030(struct snd_kcontrol *kcontrol,
  * FGAIN volume control:
  * from -62 to 0 dB in 1 dB steps (mute instead of -63 dB)
  */
-static DECLARE_TLV_DB_SCALE(master_tlv, -6300, 100, 1);
+static DECLARE_TLV_DB_SCALE(digital_fine_tlv, -6300, 100, 1);
 
 /*
  * CGAIN volume control:
  * 0 dB to 12 dB in 6 dB steps
  * value 2 and 3 means 12 dB
  */
-static DECLARE_TLV_DB_SCALE(master_coarse_tlv, 0, 600, 0);
+static DECLARE_TLV_DB_SCALE(digital_coarse_tlv, 0, 600, 0);
+
+/*
+ * Analog playback gain
+ * -24 dB to 12 dB in 2 dB steps
+ */
+static DECLARE_TLV_DB_SCALE(analog_tlv, -2400, 200, 0);
 
 /*
  * Capture gain after the ADCs
@@ -367,12 +373,27 @@ static DECLARE_TLV_DB_SCALE(master_coarse_tlv, 0, 600, 0);
 static DECLARE_TLV_DB_SCALE(digital_capture_tlv, 0, 100, 0);
 
 static const struct snd_kcontrol_new twl4030_snd_controls[] = {
-	SOC_DOUBLE_R_TLV("Master Playback Volume",
-		 TWL4030_REG_ARXL2PGA, TWL4030_REG_ARXR2PGA,
-		0, 0x3f, 0, master_tlv),
-	SOC_DOUBLE_R_TLV("Master PCM Playback Volume",
-		 TWL4030_REG_ARXL2PGA, TWL4030_REG_ARXR2PGA,
-		6, 0x2, 0, master_coarse_tlv),
+	/* Common playback gain controls */
+	SOC_DOUBLE_R_TLV("DAC1 Digital Fine Playback Volume",
+		TWL4030_REG_ARXL1PGA, TWL4030_REG_ARXR1PGA,
+		0, 0x3f, 0, digital_fine_tlv),
+	SOC_DOUBLE_R_TLV("DAC2 Digital Fine Playback Volume",
+		TWL4030_REG_ARXL2PGA, TWL4030_REG_ARXR2PGA,
+		0, 0x3f, 0, digital_fine_tlv),
+
+	SOC_DOUBLE_R_TLV("DAC1 Digital Coarse Playback Volume",
+		TWL4030_REG_ARXL1PGA, TWL4030_REG_ARXR1PGA,
+		6, 0x2, 0, digital_coarse_tlv),
+	SOC_DOUBLE_R_TLV("DAC2 Digital Coarse Playback Volume",
+		TWL4030_REG_ARXL2PGA, TWL4030_REG_ARXR2PGA,
+		6, 0x2, 0, digital_coarse_tlv),
+
+	SOC_DOUBLE_R_TLV("DAC1 Analog Playback Volume",
+		TWL4030_REG_ARXL1_APGA_CTL, TWL4030_REG_ARXR1_APGA_CTL,
+		3, 0x12, 1, analog_tlv),
+	SOC_DOUBLE_R_TLV("DAC2 Analog Playback Volume",
+		TWL4030_REG_ARXL2_APGA_CTL, TWL4030_REG_ARXR2_APGA_CTL,
+		3, 0x12, 1, analog_tlv),
 
 	/* Common capture gain controls */
 	SOC_DOUBLE_R_TLV("Capture Volume",
-- 
1.5.6.5

^ permalink raw reply related	[flat|nested] 13+ messages in thread

* [PATCH 6/7] ASoC: TWL4030: Add volume controls for outputs
  2008-12-01 20:07         ` [PATCH 5/7] ASoC: TWL4030: Change the common playback volume controls Mark Brown
@ 2008-12-01 20:07           ` Mark Brown
  2008-12-01 20:07             ` [PATCH 7/7] ASoC: Don't free static data in WM9713 Mark Brown
  2008-12-05  4:44             ` [PATCH 6/7] ASoC: TWL4030: Add volume controls for outputs naveen krishna ch
  0 siblings, 2 replies; 13+ messages in thread
From: Mark Brown @ 2008-12-01 20:07 UTC (permalink / raw)
  To: Takashi Iwai; +Cc: alsa-devel, Mark Brown, Peter Ujfalusi

From: Peter Ujfalusi <peter.ujfalusi@nokia.com>

All outputs have dedicated gain controls except the
HandsFree output.

Signed-off-by: Peter Ujfalusi <peter.ujfalusi@nokia.com>
Signed-off-by: Mark Brown <broonie@opensource.wolfsonmicro.com>
---
 sound/soc/codecs/twl4030.c |   21 +++++++++++++++++++++
 1 files changed, 21 insertions(+), 0 deletions(-)

diff --git a/sound/soc/codecs/twl4030.c b/sound/soc/codecs/twl4030.c
index 1dae73a..ffd5120 100644
--- a/sound/soc/codecs/twl4030.c
+++ b/sound/soc/codecs/twl4030.c
@@ -367,6 +367,12 @@ static DECLARE_TLV_DB_SCALE(digital_coarse_tlv, 0, 600, 0);
 static DECLARE_TLV_DB_SCALE(analog_tlv, -2400, 200, 0);
 
 /*
+ * Gain controls tied to outputs
+ * -6 dB to 6 dB in 6 dB steps (mute instead of -12)
+ */
+static DECLARE_TLV_DB_SCALE(output_tvl, -1200, 600, 1);
+
+/*
  * Capture gain after the ADCs
  * from 0 dB to 31 dB in 1 dB steps
  */
@@ -395,6 +401,21 @@ static const struct snd_kcontrol_new twl4030_snd_controls[] = {
 		TWL4030_REG_ARXL2_APGA_CTL, TWL4030_REG_ARXR2_APGA_CTL,
 		3, 0x12, 1, analog_tlv),
 
+	/* Separate output gain controls */
+	SOC_DOUBLE_R_TLV_TWL4030("PreDriv Playback Volume",
+		TWL4030_REG_PREDL_CTL, TWL4030_REG_PREDR_CTL,
+		4, 3, 0, output_tvl),
+
+	SOC_DOUBLE_TLV_TWL4030("Headset Playback Volume",
+		TWL4030_REG_HS_GAIN_SET, 0, 2, 3, 0, output_tvl),
+
+	SOC_DOUBLE_R_TLV_TWL4030("Carkit Playback Volume",
+		TWL4030_REG_PRECKL_CTL, TWL4030_REG_PRECKR_CTL,
+		4, 3, 0, output_tvl),
+
+	SOC_SINGLE_TLV_TWL4030("Earpiece Playback Volume",
+		TWL4030_REG_EAR_CTL, 4, 3, 0, output_tvl),
+
 	/* Common capture gain controls */
 	SOC_DOUBLE_R_TLV("Capture Volume",
 		TWL4030_REG_ATXL1PGA, TWL4030_REG_ATXR1PGA,
-- 
1.5.6.5

^ permalink raw reply related	[flat|nested] 13+ messages in thread

* [PATCH 7/7] ASoC: Don't free static data in WM9713
  2008-12-01 20:07           ` [PATCH 6/7] ASoC: TWL4030: Add volume controls for outputs Mark Brown
@ 2008-12-01 20:07             ` Mark Brown
  2008-12-05  4:44             ` [PATCH 6/7] ASoC: TWL4030: Add volume controls for outputs naveen krishna ch
  1 sibling, 0 replies; 13+ messages in thread
From: Mark Brown @ 2008-12-01 20:07 UTC (permalink / raw)
  To: Takashi Iwai; +Cc: alsa-devel, Mark Brown

Signed-off-by: Mark Brown <broonie@opensource.wolfsonmicro.com>
---
 sound/soc/codecs/wm9713.c |    1 -
 1 files changed, 0 insertions(+), 1 deletions(-)

diff --git a/sound/soc/codecs/wm9713.c b/sound/soc/codecs/wm9713.c
index 49962a8..f3ca8aa 100644
--- a/sound/soc/codecs/wm9713.c
+++ b/sound/soc/codecs/wm9713.c
@@ -1283,7 +1283,6 @@ static int wm9713_soc_remove(struct platform_device *pdev)
 	snd_soc_free_ac97_codec(codec);
 	kfree(codec->private_data);
 	kfree(codec->reg_cache);
-	kfree(codec->dai);
 	kfree(codec);
 	return 0;
 }
-- 
1.5.6.5

^ permalink raw reply related	[flat|nested] 13+ messages in thread

* Re: [PATCH 0/7] ASoC updates
  2008-12-01 20:07 [PATCH 0/7] ASoC updates Mark Brown
  2008-12-01 20:07 ` [PATCH 1/7] ASoC: Rename snd_soc_register_card() to snd_soc_init_card() Mark Brown
@ 2008-12-01 20:31 ` Takashi Iwai
  1 sibling, 0 replies; 13+ messages in thread
From: Takashi Iwai @ 2008-12-01 20:31 UTC (permalink / raw)
  To: Mark Brown; +Cc: alsa-devel

At Mon, 1 Dec 2008 20:07:03 +0000,
Mark Brown wrote:
> 
> The following changes since commit 682d5874f3d654b5d13d9b8dd56b9e05cfadd01b:
>   Takashi Iwai (1):
>         ALSA: ASoC: Fix old-style trigger callback in s3c2443-ac97.c
> 
> are available in the git repository at:
> 
>   git://opensource.wolfsonmicro.com/linux-2.6-asoc for-tiwai

Pulled now.  Thanks.


Takashi

> 
> Mark Brown (4):
>       ASoC: Rename snd_soc_register_card() to snd_soc_init_card()
>       ASoC: Annotate core removal function
>       ASoC: Remove in-code changelog from AD73311 driver
>       ASoC: Don't free static data in WM9713
> 
> Peter Ujfalusi (3):
>       ASoC: TWL4030: Change the capture volume control to TLV
>       ASoC: TWL4030: Change the common playback volume controls
>       ASoC: TWL4030: Add volume controls for outputs
> 
>  include/sound/soc.h            |    2 +-
>  sound/soc/codecs/ac97.c        |    2 +-
>  sound/soc/codecs/ad1980.c      |    2 +-
>  sound/soc/codecs/ad73311.c     |    5 +--
>  sound/soc/codecs/ak4535.c      |    2 +-
>  sound/soc/codecs/cs4270.c      |    2 +-
>  sound/soc/codecs/pcm3008.c     |    2 +-
>  sound/soc/codecs/ssm2602.c     |    2 +-
>  sound/soc/codecs/tlv320aic23.c |    2 +-
>  sound/soc/codecs/tlv320aic26.c |    2 +-
>  sound/soc/codecs/tlv320aic3x.c |    2 +-
>  sound/soc/codecs/twl4030.c     |   74 +++++++++++++++++++++++++++++++++------
>  sound/soc/codecs/uda134x.c     |    2 +-
>  sound/soc/codecs/uda1380.c     |    2 +-
>  sound/soc/codecs/wm8510.c      |    2 +-
>  sound/soc/codecs/wm8580.c      |    2 +-
>  sound/soc/codecs/wm8728.c      |    2 +-
>  sound/soc/codecs/wm8731.c      |    2 +-
>  sound/soc/codecs/wm8750.c      |    2 +-
>  sound/soc/codecs/wm8753.c      |    2 +-
>  sound/soc/codecs/wm8900.c      |    2 +-
>  sound/soc/codecs/wm8903.c      |    2 +-
>  sound/soc/codecs/wm8971.c      |    2 +-
>  sound/soc/codecs/wm8990.c      |    2 +-
>  sound/soc/codecs/wm9712.c      |    2 +-
>  sound/soc/codecs/wm9713.c      |    3 +-
>  sound/soc/soc-core.c           |    8 ++--
>  27 files changed, 91 insertions(+), 45 deletions(-)
> 

^ permalink raw reply	[flat|nested] 13+ messages in thread

* Re: [PATCH 6/7] ASoC: TWL4030: Add volume controls for outputs
  2008-12-01 20:07           ` [PATCH 6/7] ASoC: TWL4030: Add volume controls for outputs Mark Brown
  2008-12-01 20:07             ` [PATCH 7/7] ASoC: Don't free static data in WM9713 Mark Brown
@ 2008-12-05  4:44             ` naveen krishna ch
  2008-12-05 10:44               ` Mark Brown
  2008-12-08  7:13               ` Peter Ujfalusi
  1 sibling, 2 replies; 13+ messages in thread
From: naveen krishna ch @ 2008-12-05  4:44 UTC (permalink / raw)
  To: Mark Brown; +Cc: Takashi Iwai, alsa-devel, Peter Ujfalusi

On Tue, Dec 2, 2008 at 1:37 AM, Mark Brown <
broonie@opensource.wolfsonmicro.com> wrote:

> From: Peter Ujfalusi <peter.ujfalusi@nokia.com>
>
> All outputs have dedicated gain controls except the
> HandsFree output.
>
> Signed-off-by: Peter Ujfalusi <peter.ujfalusi@nokia.com>
> Signed-off-by: Mark Brown <broonie@opensource.wolfsonmicro.com>
> ---
>  sound/soc/codecs/twl4030.c |   21 +++++++++++++++++++++
>  1 files changed, 21 insertions(+), 0 deletions(-)
>
> diff --git a/sound/soc/codecs/twl4030.c b/sound/soc/codecs/twl4030.c
> index 1dae73a..ffd5120 100644
> --- a/sound/soc/codecs/twl4030.c
> +++ b/sound/soc/codecs/twl4030.c
> @@ -367,6 +367,12 @@ static DECLARE_TLV_DB_SCALE(digital_coarse_tlv, 0,
> 600, 0);
>  static DECLARE_TLV_DB_SCALE(analog_tlv, -2400, 200, 0);
>
>  /*
> + * Gain controls tied to outputs
> + * -6 dB to 6 dB in 6 dB steps (mute instead of -12)
> + */
> +static DECLARE_TLV_DB_SCALE(output_tvl, -1200, 600, 1);
> +
> +/*
>  * Capture gain after the ADCs
>  * from 0 dB to 31 dB in 1 dB steps
>  */
> @@ -395,6 +401,21 @@ static const struct snd_kcontrol_new
> twl4030_snd_controls[] = {
>                TWL4030_REG_ARXL2_APGA_CTL, TWL4030_REG_ARXR2_APGA_CTL,
>                3, 0x12, 1, analog_tlv),
>
> +       /* Separate output gain controls */
> +       SOC_DOUBLE_R_TLV_TWL4030("",
> +               TWL4030_REG_PREDL_CTL, TWL4030_REG_PREDR_CTL,
> +               4, 3, 0, output_tvl),

With this implementation the
#amixer cset numid=16 3
numid=16,iface=MIXER,name='PreDriv Playback Volume'
  ; type=INTEGER,access=rw---R--,values=2,min=0,max=209,step=0
  : values=3,3
  | dBscale-min=-12.00dB,step=6.00dB,mute=1
The min and max values are from 0 to 209 and they r repeating for every 4
steps
Can any one explain this


>
> +
> +       SOC_DOUBLE_TLV_TWL4030("Headset Playback Volume",
> +               TWL4030_REG_HS_GAIN_SET, 0, 2, 3, 0, output_tvl),

With this implementation the min and max values seems to be shown like 0 to
60 instead of 0 to 3
and  the range is repeatring between 0 to 60
Means 4 again 0 and 7 a bit max, its repeating..

>
> +
> +       SOC_DOUBLE_R_TLV_TWL4030("Carkit Playback Volume",
> +               TWL4030_REG_PRECKL_CTL, TWL4030_REG_PRECKR_CTL,
> +               4, 3, 0, output_tvl),
> +
> +       SOC_SINGLE_TLV_TWL4030("Earpiece Playback Volume",
> +               TWL4030_REG_EAR_CTL, 4, 3, 0, output_tvl),
> +
>        /* Common capture gain controls */
>        SOC_DOUBLE_R_TLV("Capture Volume",
>                TWL4030_REG_ATXL1PGA, TWL4030_REG_ATXR1PGA,
> --
> 1.5.6.5
>
> _______________________________________________
> Alsa-devel mailing list
> Alsa-devel@alsa-project.org
> http://mailman.alsa-project.org/mailman/listinfo/alsa-devel
>



Thanks ,,

(: Naveen Krishna Ch :)

^ permalink raw reply	[flat|nested] 13+ messages in thread

* Re: [PATCH 6/7] ASoC: TWL4030: Add volume controls for outputs
  2008-12-05  4:44             ` [PATCH 6/7] ASoC: TWL4030: Add volume controls for outputs naveen krishna ch
@ 2008-12-05 10:44               ` Mark Brown
  2008-12-05 11:17                 ` naveen krishna ch
  2008-12-08  7:13               ` Peter Ujfalusi
  1 sibling, 1 reply; 13+ messages in thread
From: Mark Brown @ 2008-12-05 10:44 UTC (permalink / raw)
  To: naveen krishna ch; +Cc: Takashi Iwai, alsa-devel, Peter Ujfalusi

On Fri, Dec 05, 2008 at 10:14:35AM +0530, naveen krishna ch wrote:

> The min and max values are from 0 to 209 and they r repeating for every 4
> steps
> Can any one explain this

Does this patch help?

diff --git a/sound/soc/codecs/twl4030.c b/sound/soc/codecs/twl4030.c
index 3c9fdf2..afda2fc 100644
--- a/sound/soc/codecs/twl4030.c
+++ b/sound/soc/codecs/twl4030.c
@@ -223,7 +223,7 @@ static void twl4030_init_chip(struct snd_soc_codec *codec)
 	.put = snd_soc_put_volsw_r2_twl4030, \
 	.private_value = (unsigned long)&(struct soc_mixer_control) \
 		{.reg = reg_left, .rreg = reg_right, .shift = xshift, \
-		.max = xmax, .invert = xinvert} }
+		 .rshift = xshift, .max = xmax, .invert = xinvert} }
 #define SOC_SINGLE_TLV_TWL4030(xname, xreg, xshift, xmax, xinvert, tlv_array) \
 	SOC_DOUBLE_TLV_TWL4030(xname, xreg, xshift, xshift, xmax, \
 			       xinvert, tlv_array)

^ permalink raw reply related	[flat|nested] 13+ messages in thread

* Re: [PATCH 6/7] ASoC: TWL4030: Add volume controls for outputs
  2008-12-05 10:44               ` Mark Brown
@ 2008-12-05 11:17                 ` naveen krishna ch
  0 siblings, 0 replies; 13+ messages in thread
From: naveen krishna ch @ 2008-12-05 11:17 UTC (permalink / raw)
  To: Mark Brown; +Cc: Takashi Iwai, alsa-devel, Peter Ujfalusi

On Fri, Dec 5, 2008 at 4:14 PM, Mark Brown <
broonie@opensource.wolfsonmicro.com> wrote:

> On Fri, Dec 05, 2008 at 10:14:35AM +0530, naveen krishna ch wrote:
>
> > The min and max values are from 0 to 209 and they r repeating for every 4
> > steps
> > Can any one explain this
>
> Does this patch help?
>
> diff --git a/sound/soc/codecs/twl4030.c b/sound/soc/codecs/twl4030.c
> index 3c9fdf2..afda2fc 100644
> --- a/sound/soc/codecs/twl4030.c
> +++ b/sound/soc/codecs/twl4030.c
> @@ -223,7 +223,7 @@ static void twl4030_init_chip(struct snd_soc_codec
> *codec)
>        .put = snd_soc_put_volsw_r2_twl4030, \
>        .private_value = (unsigned long)&(struct soc_mixer_control) \
>                {.reg = reg_left, .rreg = reg_right, .shift = xshift, \
> -               .max = xmax, .invert = xinvert} }
> +                .rshift = xshift, .max = xmax, .invert = xinvert} }
>  #define SOC_SINGLE_TLV_TWL4030(xname, xreg, xshift, xmax, xinvert,
> tlv_array) \
>        SOC_DOUBLE_TLV_TWL4030(xname, xreg, xshift, xshift, xmax, \
>                               xinvert, tlv_array)

I am afraid But it dint help.
The desired affect is repeating itself between 0 to 60 range.



diff --git a/sound/soc/soc-core.c b/sound/soc/soc-core.c
index 13b4aaf..0448708 100644
--- a/sound/soc/soc-core.c
+++ b/sound/soc/soc-core.c
@@ -1233,7 +1233,7 @@ int snd_soc_new_pcms(struct snd_soc_device *socdev, int idx, const char *xid)
 EXPORT_SYMBOL_GPL(snd_soc_new_pcms);
 
 /**
  * snd_soc_register_card - register sound card
  * @socdev: the SoC audio device
  *
  * Register a SoC sound card. Also registers an AC97 device if the
@@ -1241,7 +1241,7 @@ EXPORT_SYMBOL_GPL(snd_soc_new_pcms);
  *
  * Returns 0 for success, else error.
  */
-int snd_soc_register_card(struct snd_soc_device *socdev)
+int snd_soc_init_card(struct snd_soc_device *socdev)
 {
 	struct snd_soc_codec *codec = socdev->codec;
 	struct snd_soc_card *card = socdev->card;
@@ -1298,7 +1298,7 @@ int snd_soc_register_card(struct snd_soc_device *socdev)
 out:
 	return ret;
 }
-EXPORT_SYMBOL_GPL(snd_soc_register_card);
+EXPORT_SYMBOL_GPL(snd_soc_init_card);
 
 /**
  * snd_soc_free_pcms - free sound card and pcms
@@ -1233,7 +1233,7 @@ int snd_soc_new_pcms(struct snd_soc_device *socdev, int idx, const char *xid)
 
 /**
- * snd_soc_register_card - register sound card
+ * snd_soc_init_card - register sound card
  * @socdev: the SoC audio device
  *
-- 
Thanks,

(: Naveen Krishna Ch :)

^ permalink raw reply	[flat|nested] 13+ messages in thread

* Re: [PATCH 6/7] ASoC: TWL4030: Add volume controls for outputs
  2008-12-05  4:44             ` [PATCH 6/7] ASoC: TWL4030: Add volume controls for outputs naveen krishna ch
  2008-12-05 10:44               ` Mark Brown
@ 2008-12-08  7:13               ` Peter Ujfalusi
  1 sibling, 0 replies; 13+ messages in thread
From: Peter Ujfalusi @ 2008-12-08  7:13 UTC (permalink / raw)
  To: ext naveen krishna ch; +Cc: Takashi Iwai, alsa-devel, Mark Brown

Hello,

interesting...

On Friday 05 December 2008 06:44:35 ext naveen krishna ch wrote:
> On Tue, Dec 2, 2008 at 1:37 AM, Mark Brown
> <broonie@opensource.wolfsonmicro.com> wrote:
>
>
> With this implementation the
> #amixer cset numid=16 3
> numid=16,iface=MIXER,name='PreDriv Playback Volume'
>   ; type=INTEGER,access=rw---R--,values=2,min=0,max=209,step=0
>
>   : values=3,3
>   :
>   | dBscale-min=-12.00dB,step=6.00dB,mute=1
>
> Thanks ,,
>
> (: Naveen Krishna Ch :)

I have other patches on top of that, so the numid is different, but it gives:
# amixer cset numid=7 3
numid=7,iface=MIXER,name='PreDriv Playback Volume'
  ; type=INTEGER,access=rw---R--,values=2,min=0,max=3,step=0
  : values=3,3
  | dBscale-min=-12.00dB,step=6.00dB,mute=1


-- 
Péter

^ permalink raw reply	[flat|nested] 13+ messages in thread

end of thread, other threads:[~2008-12-08  7:14 UTC | newest]

Thread overview: 13+ messages (download: mbox.gz follow: Atom feed
-- links below jump to the message on this page --
2008-12-01 20:07 [PATCH 0/7] ASoC updates Mark Brown
2008-12-01 20:07 ` [PATCH 1/7] ASoC: Rename snd_soc_register_card() to snd_soc_init_card() Mark Brown
2008-12-01 20:07   ` [PATCH 2/7] ASoC: Annotate core removal function Mark Brown
2008-12-01 20:07     ` [PATCH 3/7] ASoC: Remove in-code changelog from AD73311 driver Mark Brown
2008-12-01 20:07       ` [PATCH 4/7] ASoC: TWL4030: Change the capture volume control to TLV Mark Brown
2008-12-01 20:07         ` [PATCH 5/7] ASoC: TWL4030: Change the common playback volume controls Mark Brown
2008-12-01 20:07           ` [PATCH 6/7] ASoC: TWL4030: Add volume controls for outputs Mark Brown
2008-12-01 20:07             ` [PATCH 7/7] ASoC: Don't free static data in WM9713 Mark Brown
2008-12-05  4:44             ` [PATCH 6/7] ASoC: TWL4030: Add volume controls for outputs naveen krishna ch
2008-12-05 10:44               ` Mark Brown
2008-12-05 11:17                 ` naveen krishna ch
2008-12-08  7:13               ` Peter Ujfalusi
2008-12-01 20:31 ` [PATCH 0/7] ASoC updates Takashi Iwai

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox